@@ -2,8 +2,11 @@ import click
 import os, shutil
 import re
 import sys
+import platform
 import subprocess
 
+isWindows = platform.system() == 'Windows'
+
 __location__ = os.path.realpath(
     os.path.join(os.getcwd(), os.path.dirname(__file__)))
 
@@ -414,10 +417,16 @@ def create_dvc_init_file():
 def run_dvc_init():
     if not os.path.isdir(directories['main'] + '/.dvc'):
         os.chdir(directories['main'])
-        subprocess.call('dvc_init.sh', shell=True)
+        command = 'dvc_init.sh'
+        if not isWindows:
+            command = './' + command
+            os.chmod(command)
+        subprocess.call(command, shell=True)
 
 def copy_deploy_files(main_dir):
     currentPipelineFolder = os.path.basename(os.getcwd())
+    if main_dir:
+        currentPipelineFolder = main_dir
     dir = os.path.join(__location__, 'cli/tester/deploy_files/')
     listOfFiles = list()
     for (dirpath, dirname, filenames) in os.walk(dir):
