@@ -1,4 +1,4 @@
-from generatedDirectory.pipeline import generatedProjectNamePipeline
+from pipeline.pipeline import generatedProjectNamePipeline
 
 if __name__ == '__main__':
     p = generatedProjectNamePipeline()
