@@ -8,7 +8,7 @@
 # get repo name (see https://stackoverflow.com/questions/15715825/how-do-you-get-the-git-repositorys-name-in-some-git-repository)
 REPO_NAME=$(basename -s .git `git config --get remote.origin.url`)
 DVC_BUCKET=gs://dozi-stg-ds-apps-1-ds-apps-ds-ml-artifacts
-dvc init
+dvc init --no-scm
 dvc config core.analytics false
 dvc remote add --default ds-ml-artifacts ${DVC_BUCKET}/${REPO_NAME}
 dvc remote modify ds-ml-artifacts projectname dozi-stg-ds-apps-1
